@@ -25,9 +25,6 @@
 
 #include "glines.h"
 
-#undef VERSION
-#define VERSION "1.9.0"
-
 GtkWidget *bah_window = NULL;
 
 GtkWidget *draw_area;
@@ -785,11 +782,15 @@ game_about_callback (GtkWidget *widget, void *data)
    					        
 	about = gnome_about_new (_("Glines"), VERSION,
 			_("(C) 1997-2000 the Free Software Foundation"),
-			_("Gnome port of the once-popular Color Lines game"),
+			_("GNOME port of the once-popular Color Lines game"),
 			(const char **)authors,
 			(const char **)documenters,
 			strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 		        pixbuf);
+	
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+		
 	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW(app));
 	g_signal_connect (G_OBJECT(about), "destroy",
 		G_CALLBACK(gtk_widget_destroyed), &about);
