@@ -17,12 +17,18 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gdk/gdkkeysyms.h>
 
 #include "preferences.h"
 #include "../gnobots2/keylabels.h"
 #include "main.h"
 
+extern GtkWidget *drawing_area;
+
 static GtkWidget *pref_dialog = NULL;
 
 static GnibblesProperties *t_properties;
@@ -48,22 +54,27 @@ static gchar *keyboard_string (gint ksym)
 
 static void destroy_cb (GtkWidget *widget, gpointer data)
 {
-	gnibbles_properties_destroy (t_properties);
-
 	if (unpause) {
 		pause_game_cb (NULL, 0);
 		unpause = 0;
 	}
+	pref_dialog = NULL;
 }
 
-static void apply_cb (GtkWidget *widget, gint pagenum, gpointer data)
+static void apply_cb (GtkWidget *widget, gint action, gpointer data)
 {
-	if (pagenum == -1) {
-		gnibbles_properties_destroy (properties);
+	if (action == GTK_RESPONSE_ACCEPT) {
+		if (t_properties->tilesize != properties->tilesize) {
+			gtk_widget_set_size_request (GTK_WIDGET (drawing_area),
+						     t_properties->tilesize * BOARDWIDTH,
+						     t_properties->tilesize * BOARDHEIGHT);
+		}
+ 		gnibbles_properties_destroy (properties);
 		properties = gnibbles_properties_copy (t_properties);
-
 		gnibbles_properties_save (properties);
+		update_score_state ();
 	}
+	gtk_widget_destroy (widget);
 }
 
 static void game_speed_cb (GtkWidget *widget, gpointer data)
@@ -73,7 +84,6 @@ static void game_speed_cb (GtkWidget *widget, gpointer data)
 
 	if (GTK_TOGGLE_BUTTON (widget)->active) {
 		t_properties->gamespeed = (gint) data;
-		gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 	}
 }
 
@@ -85,7 +95,6 @@ static void start_level_cb (GtkWidget *widget, gpointer data)
 	t_properties->startlevel = gtk_spin_button_get_value_as_int
 		(GTK_SPIN_BUTTON (data));
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void random_order_cb (GtkWidget *widget, gpointer data)
@@ -96,7 +105,7 @@ static void random_order_cb (GtkWidget *widget, gpointer data)
 	if (!pref_dialog)
 		return;
 
-	list = gtk_container_children (GTK_CONTAINER (widget->parent));
+	list = gtk_container_get_children (GTK_CONTAINER (widget->parent));
 	list = g_list_reverse (list);
 
 	if (GTK_TOGGLE_BUTTON (widget)->active) {
@@ -113,7 +122,6 @@ static void random_order_cb (GtkWidget *widget, gpointer data)
 
 	g_list_free (list);
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void fake_bonus_cb (GtkWidget *widget, gpointer data)
@@ -126,7 +134,6 @@ static void fake_bonus_cb (GtkWidget *widget, gpointer data)
 	else
 		t_properties->fakes = 0;
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void sound_cb (GtkWidget *widget, gpointer data)
@@ -139,7 +146,16 @@ static void sound_cb (GtkWidget *widget, gpointer data)
 	else
 		t_properties->sound = 0;
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
+}
+
+static void tile_size_cb (GtkWidget *widget, gpointer data)
+{
+  if (!pref_dialog)
+    return;
+
+  if (GTK_TOGGLE_BUTTON (widget)->active) {
+    t_properties->tilesize = (gint) data;
+  }
 }
 
 static void num_worms_cb (GtkWidget *widget, gpointer data)
@@ -150,7 +166,6 @@ static void num_worms_cb (GtkWidget *widget, gpointer data)
 	t_properties->numworms = gtk_spin_button_get_value_as_int
 		(GTK_SPIN_BUTTON (data));
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void worm_up_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
@@ -163,7 +178,6 @@ static void worm_up_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
 	t_properties->wormprops[(gint) data]->up = event->keyval;
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void worm_down_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
@@ -176,7 +190,6 @@ static void worm_down_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
 	t_properties->wormprops[(gint) data]->down = event->keyval;
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void worm_left_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
@@ -189,7 +202,6 @@ static void worm_left_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
 	t_properties->wormprops[(gint) data]->left = event->keyval;
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void worm_right_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
@@ -202,7 +214,6 @@ static void worm_right_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
 	t_properties->wormprops[(gint) data]->right = event->keyval;
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void set_worm_color_cb (GtkWidget *widget, gpointer data)
@@ -212,7 +223,6 @@ static void set_worm_color_cb (GtkWidget *widget, gpointer data)
 
 	t_properties->wormprops[worm]->color = color;
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 static void worm_relative_movement_cb (GtkWidget *widget, gpointer data)
@@ -223,7 +233,7 @@ static void worm_relative_movement_cb (GtkWidget *widget, gpointer data)
 	if (!pref_dialog)
 		return;
 
-	list = gtk_container_children (GTK_CONTAINER (widget->parent));
+	list = gtk_container_get_children (GTK_CONTAINER (widget->parent));
 	list = g_list_reverse (list);
 	
 	if (GTK_TOGGLE_BUTTON (widget)->active) {
@@ -242,11 +252,11 @@ static void worm_relative_movement_cb (GtkWidget *widget, gpointer data)
 
 	g_list_free (list);
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (pref_dialog));
 }
 
 void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 {
+	GtkWidget *notebook;
 	GtkWidget *label;
 	GtkWidget *hbox;
 	GtkWidget *frame;
@@ -267,7 +277,10 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 	gint running = 0;
 	
 	if (pref_dialog)
+	{
+		gtk_window_present (GTK_WINDOW(pref_dialog));
 		return;
+	}
 
 	if (!paused) {
 		unpause = 1;
@@ -279,31 +292,32 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 
 	t_properties = gnibbles_properties_copy (properties);
 
-	pref_dialog = gnome_property_box_new ();
-	gnome_dialog_set_parent (GNOME_DIALOG (pref_dialog), GTK_WINDOW
-			(window));
-	gtk_window_set_title (GTK_WINDOW (pref_dialog),
-			_("Gnibbles Preferences"));
-	gtk_signal_connect (GTK_OBJECT (pref_dialog), "destroy",
-			GTK_SIGNAL_FUNC (gtk_widget_destroyed), &pref_dialog);
-	gtk_signal_connect (GTK_OBJECT (pref_dialog), "destroy",
-			GTK_SIGNAL_FUNC (destroy_cb), NULL);
+	pref_dialog = gtk_dialog_new_with_buttons (_("Gnibbles Preferences"),
+			GTK_WINDOW(window),
+			0,
+			GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+
+	notebook = gtk_notebook_new();
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (pref_dialog)->vbox),
+			notebook);
+	gtk_widget_show (notebook);
 
 	label = gtk_label_new (_("Game"));
 	gtk_widget_show (label);
 
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
-	gtk_container_border_width (GTK_CONTAINER (hbox), GNOME_PAD);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), GNOME_PAD);
 	gtk_widget_show (hbox);
 
 	frame = gtk_frame_new (_("Speed"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 0);
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 0);
 	if (running)
 		gtk_widget_set_sensitive (frame, FALSE);
 	gtk_widget_show (frame);
 
 	vbox = gtk_vbox_new (TRUE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
 	gtk_widget_show (vbox);
 
 	button = gtk_radio_button_new_with_label (NULL, _("Nibbles newbie"));
@@ -312,30 +326,30 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 	if (properties->gamespeed == 4)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
 			(game_speed_cb), (gpointer) 4);
 
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("My second day"));
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	if (properties->gamespeed == 3)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
 			(game_speed_cb), (gpointer) 3);
 
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)), _("Not too shabby"));
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	if (properties->gamespeed == 2)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
 			(game_speed_cb), (gpointer) 2);
 
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group
 			(GTK_RADIO_BUTTON (button)),
 			_("Finger-twitching good"));
 	gtk_widget_show (button);
@@ -343,7 +357,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 	if (properties->gamespeed == 1)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
 			(game_speed_cb), (gpointer) 1);
 
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
@@ -376,7 +390,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_widget_set_sensitive (GTK_WIDGET (levelspinner), FALSE);
 	gtk_table_attach (GTK_TABLE (table), levelspinner, 1, 2, 3, 4,
 			GTK_EXPAND | GTK_FILL, 0, 0, 0);
-	gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
+	g_signal_connect (GTK_OBJECT (adjustment), "value_changed",
 			GTK_SIGNAL_FUNC (start_level_cb), levelspinner);
 
 	button = gtk_check_button_new_with_label (_("Levels in random order"));
@@ -388,7 +402,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 	if (properties->random)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
 			(random_order_cb), NULL);
 
 	button = gtk_check_button_new_with_label (_("Fake bonuses"));
@@ -400,7 +414,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 	if (properties->fakes)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
 			(fake_bonus_cb), NULL);
 
 	button = gtk_check_button_new_with_label (_("Sounds"));
@@ -410,7 +424,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 	gtk_widget_show (button);
 	gtk_table_attach (GTK_TABLE (table), button, 0, 2, 2, 3,
 			GTK_EXPAND | GTK_FILL, 0, 0, 0);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
 			(sound_cb), NULL);
 
 	label2 = gtk_label_new (_("Number of players: "));
@@ -431,12 +445,93 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 			GTK_FILL, 0, 0, 0);
 	if (running)
 		gtk_widget_set_sensitive (button, FALSE);
-	gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
+	g_signal_connect (GTK_OBJECT (adjustment), "value_changed",
 			GTK_SIGNAL_FUNC (num_worms_cb), button);
 
 	gtk_box_pack_start (GTK_BOX (hbox), table, TRUE, TRUE, 0);
 
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX (pref_dialog),
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
+			hbox, label);
+
+  label = gtk_label_new (_("Graphics"));
+  gtk_widget_show (label);
+
+	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), GNOME_PAD);
+	gtk_widget_show (hbox);
+
+	frame = gtk_frame_new (_("Board size"));
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 0);
+	gtk_widget_show (frame);
+
+	vbox = gtk_vbox_new (TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
+	gtk_widget_show (vbox);
+
+	button = gtk_radio_button_new_with_label (NULL, _("Tiny (184x132)"));
+	gtk_widget_show (button);
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	if (properties->tilesize == 2)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
+				TRUE);
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+			(tile_size_cb), (gpointer) 2);
+
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group (GTK_RADIO_BUTTON(button)),
+                                            _("Small (368x264)"));
+	gtk_widget_show (button);
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	if (properties->tilesize == 4)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
+				TRUE);
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+			(tile_size_cb), (gpointer) 4);
+
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group (GTK_RADIO_BUTTON(button)),
+                                            _("Medium (460x330)"));
+	gtk_widget_show (button);
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	if (properties->tilesize == 5)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
+				TRUE);
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+			(tile_size_cb), (gpointer) 5);
+
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group (GTK_RADIO_BUTTON(button)),
+                                            _("Large (736x528)"));
+	gtk_widget_show (button);
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	if (properties->tilesize == 8)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
+				TRUE);
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+			(tile_size_cb), (gpointer) 8);
+
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group (GTK_RADIO_BUTTON(button)),
+                                            _("Extra large (920x660)"));
+	gtk_widget_show (button);
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	if (properties->tilesize == 10)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
+				TRUE);
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+			(tile_size_cb), (gpointer) 10);
+
+	button = gtk_radio_button_new_with_label (gtk_radio_button_get_group (GTK_RADIO_BUTTON(button)),
+                                            _("Huge (1840x1320)"));
+	gtk_widget_show (button);
+	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	if (properties->tilesize == 20)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
+				TRUE);
+	g_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
+			(tile_size_cb), (gpointer) 20);
+
+	gtk_container_add (GTK_CONTAINER (frame), vbox);
+
+	gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
+
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
 			hbox, label);
 
 	for (i = 0; i < NUMWORMS; i++) {
@@ -445,7 +540,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_widget_show (label);
 
 		table = gtk_table_new (3, 4, FALSE);
-		gtk_container_border_width (GTK_CONTAINER (table),
+		gtk_container_set_border_width (GTK_CONTAINER (table),
 				GNOME_PAD);
 		gtk_table_set_col_spacings (GTK_TABLE (table),
 				GNOME_PAD);
@@ -468,7 +563,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1,
 				GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
 				0, 0);
-		gtk_signal_connect (GTK_OBJECT (entry), "key_press_event",
+		g_signal_connect (GTK_OBJECT (entry), "key_press_event",
 				GTK_SIGNAL_FUNC (worm_up_cb), (gpointer) i);
 
 		label2 = gtk_label_new (_("Down:"));
@@ -486,7 +581,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_table_attach (GTK_TABLE (table), entry, 3, 4, 0, 1,
 				GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
 				0, 0);
-		gtk_signal_connect (GTK_OBJECT (entry), "key_press_event",
+		g_signal_connect (GTK_OBJECT (entry), "key_press_event",
 				GTK_SIGNAL_FUNC (worm_down_cb), (gpointer) i);
 
 		label2 = gtk_label_new (_("Left:"));
@@ -504,7 +599,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2,
 				GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
 				0, 0);
-		gtk_signal_connect (GTK_OBJECT (entry), "key_press_event",
+		g_signal_connect (GTK_OBJECT (entry), "key_press_event",
 				GTK_SIGNAL_FUNC (worm_left_cb), (gpointer) i);
 
 		label2 = gtk_label_new (_("Right:"));
@@ -522,7 +617,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_table_attach (GTK_TABLE (table), entry, 3, 4, 1, 2,
 				GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
 				0, 0);
-		gtk_signal_connect (GTK_OBJECT (entry), "key_press_event",
+		g_signal_connect (GTK_OBJECT (entry), "key_press_event",
 				GTK_SIGNAL_FUNC (worm_right_cb), (gpointer) i);
 
 		label2 = gtk_label_new (_("Color:"));
@@ -536,44 +631,44 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		menu = gtk_menu_new ();
 		menuitem = gtk_menu_item_new_with_label (_("Red"));
 		gtk_widget_show (menuitem);
-		gtk_menu_append (GTK_MENU (menu), menuitem);
-		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMRED << 2 | i));
 		menuitem = gtk_menu_item_new_with_label (_("Green"));
 		gtk_widget_show (menuitem);
-		gtk_menu_append (GTK_MENU (menu), menuitem);
-		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMGREEN << 2 | i));
 		menuitem = gtk_menu_item_new_with_label (_("Blue"));
 		gtk_widget_show (menuitem);
-		gtk_menu_append (GTK_MENU (menu), menuitem);
-		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMBLUE << 2 | i));
 		menuitem = gtk_menu_item_new_with_label (_("Yellow"));
 		gtk_widget_show (menuitem);
-		gtk_menu_append (GTK_MENU (menu), menuitem);
-		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMYELLOW << 2 | i));
 		menuitem = gtk_menu_item_new_with_label (_("Cyan"));
 		gtk_widget_show (menuitem);
-		gtk_menu_append (GTK_MENU (menu), menuitem);
-		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMCYAN << 2 | i));
 		menuitem = gtk_menu_item_new_with_label (_("Purple"));
 		gtk_widget_show (menuitem);
-		gtk_menu_append (GTK_MENU (menu), menuitem);
-		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMPURPLE << 2 | i));
 		menuitem = gtk_menu_item_new_with_label (_("Gray"));
 		gtk_widget_show (menuitem);
-		gtk_menu_append (GTK_MENU (menu), menuitem);
-		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMGRAY << 2 | i));
 
@@ -591,7 +686,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		if (properties->wormprops[i]->relmove) {
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 					(button), TRUE);
-			list = gtk_container_children (GTK_CONTAINER (table));
+			list = gtk_container_get_children (GTK_CONTAINER (table));
 			list = g_list_reverse (list);
 			for (j = 0; j < 4; j++) {
 				gtk_widget_set_sensitive (GTK_WIDGET
@@ -600,7 +695,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 			}
 			g_list_free (list);
 		}
-		gtk_signal_connect (GTK_OBJECT (button), "toggled",
+		g_signal_connect (GTK_OBJECT (button), "toggled",
 				GTK_SIGNAL_FUNC (worm_relative_movement_cb),
 				(gpointer) i);
 
@@ -608,12 +703,15 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_table_attach (GTK_TABLE (table), button, 2, 4, 2, 3,
 				GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
-		gnome_property_box_append_page (GNOME_PROPERTY_BOX
-				(pref_dialog), table, label);
+		gtk_notebook_append_page (GTK_NOTEBOOK(notebook), table, label);
 	}
 
-	gtk_signal_connect (GTK_OBJECT (pref_dialog), "apply", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (pref_dialog), "response", GTK_SIGNAL_FUNC
 			(apply_cb), NULL);
-
+	g_signal_connect (GTK_OBJECT (pref_dialog), "destroy", GTK_SIGNAL_FUNC
+			(destroy_cb), NULL);
+	g_signal_connect (GTK_OBJECT (pref_dialog), "close", GTK_SIGNAL_FUNC
+			(destroy_cb), NULL);
+	
 	gtk_widget_show (pref_dialog);
 }
