@@ -57,7 +57,7 @@
 int GyahtzeeAbort = 0;  /* Abort program without playing game */
 
 static char *appID="gtali";
-static char *appName=N_("Gnome Tali");
+static char *appName=N_("GNOME Tali");
 static guint lastHighScore = 0;
 GtkWidget *ScoreList; 
 
@@ -379,12 +379,16 @@ about(GtkWidget *widget, gpointer data)
 
         about = gnome_about_new (appName, VERSION,
 				 _("(C) 1998 the Free Software Fundation"),
-				 _("Gnome Tali"),
+				 _("GNOME Tali"),
 				 (const char **)authors,
 				 (const char **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
-        gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
+		
+		if (pixbuf != NULL)
+			gdk_pixbuf_unref (pixbuf);
+		  
+		  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
 	g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
         gtk_widget_show (about);
 	return FALSE;
